Easy Calculator

Add, Subtract, multiply and divide any two numbers.

Usage:

import EasyCalculator

print(add_two_numbers(3, 2))
print(subtract_two_numbers(3, 2))
print(multiply_two_numbers(3, 2))
print(divide_two_numbers(3, 2))